@@ -16,6 +16,8 @@ const QString PRODUCTNAME( "SiBPlayer" );
 const QString PREFIX_SEARCHFOLDERS( "Folders" );
 const QString PREFIX_FILES( "Files" );
 const QString KEY_INIT( "initialized" );
+const QString KEY_ZOOMENABLED( "zoom" );
+const QString KEY_FRAMEDROPENABLED( "framedrop" );
 const QString KEY_FOLDER( "folder" );
 const QString KEY_FILENAME( "file" );
 const QString KEY_FILEPOS( "resume" );
@@ -30,6 +32,10 @@ public:
 	const QList<QString>& searchFolders();
     void addFolder( QString folder );
     void removeFolder( QString folder );
+    void setZoomEnabled( bool enabled );
+    bool zoomEnabled();
+    void setFrameDropEnabled( bool enabled );
+    bool frameDropEnabled();
 
 private:
 
@@ -42,6 +48,12 @@ private:
 
         /// Flag that indicates if settings were stored before
         bool m_initialized;
+
+        /// indicates if mplayer zoom is enabled
+        bool m_zoomEnabled;
+
+        /// indicates if mplayer frame drop is enabled
+        bool m_frameDropEnabled;
 };
 
 #endif /* SETTINGS_H_ */
