@@ -27,7 +27,7 @@ MainWindow::MainWindow()
     m_resumebutton->setFont( buttonFont );
     m_resumebutton->setGeometry( buttonLeftOffset, 135, buttonWidth, buttonHeight );
     m_resumebutton->setEnabled( false );
-    QPushButton* settingsbutton = new QPushButton( tr( "Folders" ), this );
+    QPushButton* settingsbutton = new QPushButton( tr( "Settings" ), this );
     settingsbutton->setFont( buttonFont );
     settingsbutton->setGeometry( buttonLeftOffset, 230, buttonWidth, buttonHeight );
     QPushButton* helpButton = new QPushButton( tr( "Info" ), this );
