@@ -20,13 +20,15 @@ private slots:
     void playerStarted();
     void playerExited( int exitCode, QProcess::ExitStatus exitStatus );
     void playerHasOutputData();
+    void parseFileInfoOutputData();
+    void doPlayFile();
 
 signals:
     void playerStart();
     void playerStop();
 
 public:
-    int playFile( VideoFile* file );
+    void playFile( VideoFile* file, bool zoom, bool frameDropEnabled );
     bool isPlayerRunning();
     void stop();
 
@@ -35,10 +37,22 @@ public:
      */
     void forwardKeyEvent( QKeyEvent* event );
 
+private:
+
+
+
+    /**
+     * Starts MPlayer to retrieve the video dimensions and
+     * then calculates the crop dimensions.
+     */
+    void setZoomOptions();
+
 private:
     QProcess* m_mplayer;
     VideoFile* m_currentFile; // not owned
     bool m_playerIsRunning;
+    QString m_zoomOptions;
+    bool m_frameDrop;
 };
 
 #endif // PLAYERFACADE_H
