@@ -19,6 +19,8 @@ private slots:
     void addFolderButtonClicked();
     void removeFolderButtonClicked();
     void cellClicked();
+    void zoomEnabled( bool enabled );
+    void frameDropEnabled( bool enabled );
 
 private:
     void setupFolderList();
